# Basics
Explore the essentials to start building your integrations.
  * [Choosing a Technology for Your Integration](https://help.sap.com/docs/leanix/ea/choosing-technology-for-your-integration?locale=en-US&state=PRODUCTION&version=CLOUD "Factors that you need to consider when choosing a technology for your integration.")
  * [Authentication to SAP LeanIX Services](https://help.sap.com/docs/leanix/ea/authentication-to-sap-leanix-services?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to authenticate to SAP LeanIX services.")
  * [Base URL](https://help.sap.com/docs/leanix/ea/base-url?locale=en-US&state=PRODUCTION&version=CLOUD "Learn about the SAP LeanIX base URL and how to get your subdomain value.")
